==> libggi_1.99.2.0b2.1.orig.tar.gz: libggi-2.0b2.1/default/kgi/line.c <==
/* $Id: line.c,v 1.3 1999/03/01 02:13:47 marcus Exp $
******************************************************************************

   LibGGI - kgicon specific overrides for fbcon
   drawline

   Copyright (C) 1998 Marcus Sundberg	[marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "genkgi.h"


int GGI_genkgi_drawline(ggi_visual *vis, int x, int y, int x2, int y2)
{
	if (1) {
		struct kgi_line arg;
		arg.x = x;
		arg.y = y + vis->w_frame_num*LIBGGI_VIRTY(vis);
		arg.x2 = x2;
		arg.y2 = y2 + vis->w_frame_num*LIBGGI_VIRTY(vis);
		
		if (ioctl(GENKGI_PRIV(vis)->fd, (int)ACCEL_DRAWLINE, &arg)
		    == 0) {
			return GGI_OK;
		}
		vis->opdraw->drawline = GENKGI_PRIV(vis)->drawline;
	}

	return GENKGI_PRIV(vis)->drawline(vis, x, y, x2, y2);
}

==> libggi-2.0b1.tar.gz: libggi-2.0b1/default/kgi/line.c <==
/* $Id: line.c,v 1.2 1998/11/19 01:06:28 marcus Exp $
******************************************************************************

   LibGGI - kgicon specific overrides for fbcon
   drawline

   Copyright (C) 1998 Marcus Sundberg	[marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************************
*/

#include "genkgi.h"


int GGI_genkgi_drawline(ggi_visual *vis, int x, int y, int x2, int y2)
{
	if (1) {
		struct kgi_line arg;
		arg.x = x;
		arg.y = y;
		arg.x2 = x2;
		arg.y2 = y2;
		
		if (ioctl(GENKGI_PRIV(vis)->fd, (int)ACCEL_DRAWLINE, &arg) == 0) {
			return GGI_OK;
		}
		vis->opdraw->drawline = GENKGI_PRIV(vis)->drawline;
	}
	return GENKGI_PRIV(vis)->drawline(vis, x, y, x2, y2);
}
